@@ -22,166 +22,167 @@ const invalid = [
   'https://github.com/foo/bar/issues',
 ]
 
-// assigning the constructor here is hacky, but the only way to make assertions that compare
-// a subset of properties to a found object pass as you would expect
-const GitHost = require('../lib/git-host')
-const defaults = { constructor: GitHost, type: 'github', user: 'foo', project: 'bar' }
+const defaults = { type: 'github', user: 'foo', project: 'bar' }
+// This is a valid git branch name that contains other occurences of the characters we check
+// for to determine the committish in order to test that we parse those correctly
+const committishDefaults = { committish: 'lk/br@nch.t#st:^1.0.0-pre.4' }
 const valid = {
   // extreme shorthand
   //
   // NOTE these do not accept auth at all
   'foo/bar': { ...defaults, default: 'shortcut' },
-  'foo/bar#branch': { ...defaults, default: 'shortcut', committish: 'branch' },
+  [`foo/bar#${committishDefaults.committish}`]: { ...defaults, default: 'shortcut', ...committishDefaults },
 
   'foo/bar.git': { ...defaults, default: 'shortcut' },
-  'foo/bar.git#branch': { ...defaults, default: 'shortcut', committish: 'branch' },
+  [`foo/bar.git#${committishDefaults.committish}`]: { ...defaults, default: 'shortcut', ...committishDefaults },
 
   // shortcuts
   //
   // NOTE auth is accepted but ignored
   'github:foo/bar': { ...defaults, default: 'shortcut' },
-  'github:foo/bar#branch': { ...defaults, default: 'shortcut', committish: 'branch' },
+  [`github:foo/bar#${committishDefaults.committish}`]: { ...defaults, default: 'shortcut', ...committishDefaults },
   'github:user@foo/bar': { ...defaults, default: 'shortcut', auth: null },
-  'github:user@foo/bar#branch': { ...defaults, default: 'shortcut', auth: null, committish: 'branch' },
+  [`github:user@foo/bar#${committishDefaults.committish}`]: { ...defaults, default: 'shortcut', auth: null, ...committishDefaults },
   'github:user:password@foo/bar': { ...defaults, default: 'shortcut', auth: null },
-  'github:user:password@foo/bar#branch': { ...defaults, default: 'shortcut', auth: null, committish: 'branch' },
+  [`github:user:password@foo/bar#${committishDefaults.committish}`]: { ...defaults, default: 'shortcut', auth: null, ...committishDefaults },
   'github::password@foo/bar': { ...defaults, default: 'shortcut', auth: null },
-  'github::password@foo/bar#branch': { ...defaults, default: 'shortcut', auth: null, committish: 'branch' },
+  [`github::password@foo/bar#${committishDefaults.committish}`]: { ...defaults, default: 'shortcut', auth: null, ...committishDefaults },
 
   'github:foo/bar.git': { ...defaults, default: 'shortcut' },
-  'github:foo/bar.git#branch': { ...defaults, default: 'shortcut', committish: 'branch' },
+  [`github:foo/bar.git#${committishDefaults.committish}`]: { ...defaults, default: 'shortcut', ...committishDefaults },
   'github:user@foo/bar.git': { ...defaults, default: 'shortcut', auth: null },
-  'github:user@foo/bar.git#branch': { ...defaults, default: 'shortcut', auth: null, committish: 'branch' },
+  [`github:user@foo/bar.git#${committishDefaults.committish}`]: { ...defaults, default: 'shortcut', auth: null, ...committishDefaults },
   'github:user:password@foo/bar.git': { ...defaults, default: 'shortcut', auth: null },
-  'github:user:password@foo/bar.git#branch': { ...defaults, default: 'shortcut', auth: null, committish: 'branch' },
+  [`github:user:password@foo/bar.git#${committishDefaults.committish}`]: { ...defaults, default: 'shortcut', auth: null, ...committishDefaults },
   'github::password@foo/bar.git': { ...defaults, default: 'shortcut', auth: null },
-  'github::password@foo/bar.git#branch': { ...defaults, default: 'shortcut', auth: null, committish: 'branch' },
+  [`github::password@foo/bar.git#${committishDefaults.committish}`]: { ...defaults, default: 'shortcut', auth: null, ...committishDefaults },
 
   // git urls
   //
   // NOTE auth is accepted and respected
   'git://github.com/foo/bar': { ...defaults, default: 'git' },
-  'git://github.com/foo/bar#branch': { ...defaults, default: 'git', committish: 'branch' },
+  [`git://github.com/foo/bar#${committishDefaults.committish}`]: { ...defaults, default: 'git', ...committishDefaults },
   'git://user@github.com/foo/bar': { ...defaults, default: 'git', auth: 'user' },
-  'git://user@github.com/foo/bar#branch': { ...defaults, default: 'git', auth: 'user', committish: 'branch' },
+  [`git://user@github.com/foo/bar#${committishDefaults.committish}`]: { ...defaults, default: 'git', auth: 'user', ...committishDefaults },
   'git://user:password@github.com/foo/bar': { ...defaults, default: 'git', auth: 'user:password' },
-  'git://user:password@github.com/foo/bar#branch': { ...defaults, default: 'git', auth: 'user:password', committish: 'branch' },
+  [`git://user:password@github.com/foo/bar#${committishDefaults.committish}`]: { ...defaults, default: 'git', auth: 'user:password', ...committishDefaults },
   'git://:password@github.com/foo/bar': { ...defaults, default: 'git', auth: ':password' },
-  'git://:password@github.com/foo/bar#branch': { ...defaults, default: 'git', auth: ':password', committish: 'branch' },
+  [`git://:password@github.com/foo/bar#${committishDefaults.committish}`]: { ...defaults, default: 'git', auth: ':password', ...committishDefaults },
 
   'git://github.com/foo/bar.git': { ...defaults, default: 'git' },
-  'git://github.com/foo/bar.git#branch': { ...defaults, default: 'git', committish: 'branch' },
+  [`git://github.com/foo/bar.git#${committishDefaults.committish}`]: { ...defaults, default: 'git', ...committishDefaults },
   'git://git@github.com/foo/bar.git': { ...defaults, default: 'git', auth: 'git' },
-  'git://git@github.com/foo/bar.git#branch': { ...defaults, default: 'git', auth: 'git', committish: 'branch' },
+  [`git://git@github.com/foo/bar.git#${committishDefaults.committish}`]: { ...defaults, default: 'git', auth: 'git', ...committishDefaults },
   'git://user:password@github.com/foo/bar.git': { ...defaults, default: 'git', auth: 'user:password' },
-  'git://user:password@github.com/foo/bar.git#branch': { ...defaults, default: 'git', auth: 'user:password', committish: 'branch' },
+  [`git://user:password@github.com/foo/bar.git#${committishDefaults.committish}`]: { ...defaults, default: 'git', auth: 'user:password', ...committishDefaults },
   'git://:password@github.com/foo/bar.git': { ...defaults, default: 'git', auth: ':password' },
-  'git://:password@github.com/foo/bar.git#branch': { ...defaults, default: 'git', auth: ':password', committish: 'branch' },
+  [`git://:password@github.com/foo/bar.git#${committishDefaults.committish}`]: { ...defaults, default: 'git', auth: ':password', ...committishDefaults },
 
   // no-protocol git+ssh
   //
   // NOTE auth is _required_ (see invalid list) but ignored
   'user@github.com:foo/bar': { ...defaults, default: 'sshurl', auth: null },
-  'user@github.com:foo/bar#branch': { ...defaults, default: 'sshurl', auth: null, committish: 'branch' },
+  [`user@github.com:foo/bar#${committishDefaults.committish}`]: { ...defaults, default: 'sshurl', auth: null, ...committishDefaults },
   'user:password@github.com:foo/bar': { ...defaults, default: 'sshurl', auth: null },
-  'user:password@github.com:foo/bar#branch': { ...defaults, default: 'sshurl', auth: null, committish: 'branch' },
+  [`user:password@github.com:foo/bar#${committishDefaults.committish}`]: { ...defaults, default: 'sshurl', auth: null, ...committishDefaults },
   ':password@github.com:foo/bar': { ...defaults, default: 'sshurl', auth: null },
-  ':password@github.com:foo/bar#branch': { ...defaults, default: 'sshurl', auth: null, committish: 'branch' },
+  [`:password@github.com:foo/bar#${committishDefaults.committish}`]: { ...defaults, default: 'sshurl', auth: null, ...committishDefaults },
 
   'user@github.com:foo/bar.git': { ...defaults, default: 'sshurl', auth: null },
-  'user@github.com:foo/bar.git#branch': { ...defaults, default: 'sshurl', auth: null, committish: 'branch' },
+  [`user@github.com:foo/bar.git#${committishDefaults.committish}`]: { ...defaults, default: 'sshurl', auth: null, ...committishDefaults },
   'user:password@github.com:foo/bar.git': { ...defaults, default: 'sshurl', auth: null },
-  'user:password@github.com:foo/bar.git#branch': { ...defaults, default: 'sshurl', auth: null, committish: 'branch' },
+  [`user:password@github.com:foo/bar.git#${committishDefaults.committish}`]: { ...defaults, default: 'sshurl', auth: null, ...committishDefaults },
   ':password@github.com:foo/bar.git': { ...defaults, default: 'sshurl', auth: null },
-  ':password@github.com:foo/bar.git#branch': { ...defaults, default: 'sshurl', auth: null, committish: 'branch' },
+  [`:password@github.com:foo/bar.git#${committishDefaults.committish}`]: { ...defaults, default: 'sshurl', auth: null, ...committishDefaults },
 
   // git+ssh urls
   //
   // NOTE auth is accepted but ignored
   'git+ssh://github.com:foo/bar': { ...defaults, default: 'sshurl' },
-  'git+ssh://github.com:foo/bar#branch': { ...defaults, default: 'sshurl', committish: 'branch' },
+  [`git+ssh://github.com:foo/bar#${committishDefaults.committish}`]: { ...defaults, default: 'sshurl', ...committishDefaults },
   'git+ssh://user@github.com:foo/bar': { ...defaults, default: 'sshurl', auth: null },
-  'git+ssh://user@github.com:foo/bar#branch': { ...defaults, default: 'sshurl', auth: null, committish: 'branch' },
+  [`git+ssh://user@github.com:foo/bar#${committishDefaults.committish}`]: { ...defaults, default: 'sshurl', auth: null, ...committishDefaults },
   'git+ssh://user:password@github.com:foo/bar': { ...defaults, default: 'sshurl', auth: null },
-  'git+ssh://user:password@github.com:foo/bar#branch': { ...defaults, default: 'sshurl', auth: null, committish: 'branch' },
+  [`git+ssh://user:password@github.com:foo/bar#${committishDefaults.committish}`]: { ...defaults, default: 'sshurl', auth: null, ...committishDefaults },
   'git+ssh://:password@github.com:foo/bar': { ...defaults, default: 'sshurl', auth: null },
-  'git+ssh://:password@github.com:foo/bar#branch': { ...defaults, default: 'sshurl', auth: null, committish: 'branch' },
+  [`git+ssh://:password@github.com:foo/bar#${committishDefaults.committish}`]: { ...defaults, default: 'sshurl', auth: null, ...committishDefaults },
 
   'git+ssh://github.com:foo/bar.git': { ...defaults, default: 'sshurl' },
-  'git+ssh://github.com:foo/bar.git#branch': { ...defaults, default: 'sshurl', committish: 'branch' },
+  [`git+ssh://github.com:foo/bar.git#${committishDefaults.committish}`]: { ...defaults, default: 'sshurl', ...committishDefaults },
   'git+ssh://user@github.com:foo/bar.git': { ...defaults, default: 'sshurl', auth: null },
-  'git+ssh://user@github.com:foo/bar.git#branch': { ...defaults, default: 'sshurl', auth: null, committish: 'branch' },
+  [`git+ssh://user@github.com:foo/bar.git#${committishDefaults.committish}`]: { ...defaults, default: 'sshurl', auth: null, ...committishDefaults },
   'git+ssh://user:password@github.com:foo/bar.git': { ...defaults, default: 'sshurl', auth: null },
-  'git+ssh://user:password@github.com:foo/bar.git#branch': { ...defaults, default: 'sshurl', auth: null, committish: 'branch' },
+  [`git+ssh://user:password@github.com:foo/bar.git#${committishDefaults.committish}`]: { ...defaults, default: 'sshurl', auth: null, ...committishDefaults },
   'git+ssh://:password@github.com:foo/bar.git': { ...defaults, default: 'sshurl', auth: null },
-  'git+ssh://:password@github.com:foo/bar.git#branch': { ...defaults, default: 'sshurl', auth: null, committish: 'branch' },
+  [`git+ssh://:password@github.com:foo/bar.git#${committishDefaults.committish}`]: { ...defaults, default: 'sshurl', auth: null, ...committishDefaults },
 
   // ssh urls
   //
   // NOTE auth is accepted but ignored
   'ssh://github.com:foo/bar': { ...defaults, default: 'sshurl' },
-  'ssh://github.com:foo/bar#branch': { ...defaults, default: 'sshurl', committish: 'branch' },
+  [`ssh://github.com:foo/bar#${committishDefaults.committish}`]: { ...defaults, default: 'sshurl', ...committishDefaults },
   'ssh://user@github.com:foo/bar': { ...defaults, default: 'sshurl', auth: null },
-  'ssh://user@github.com:foo/bar#branch': { ...defaults, default: 'sshurl', auth: null, committish: 'branch' },
+  [`ssh://user@github.com:foo/bar#${committishDefaults.committish}`]: { ...defaults, default: 'sshurl', auth: null, ...committishDefaults },
   'ssh://user:password@github.com:foo/bar': { ...defaults, default: 'sshurl', auth: null },
-  'ssh://user:password@github.com:foo/bar#branch': { ...defaults, default: 'sshurl', auth: null, committish: 'branch' },
+  [`ssh://user:password@github.com:foo/bar#${committishDefaults.committish}`]: { ...defaults, default: 'sshurl', auth: null, ...committishDefaults },
   'ssh://:password@github.com:foo/bar': { ...defaults, default: 'sshurl', auth: null },
-  'ssh://:password@github.com:foo/bar#branch': { ...defaults, default: 'sshurl', auth: null, committish: 'branch' },
+  [`ssh://:password@github.com:foo/bar#${committishDefaults.committish}`]: { ...defaults, default: 'sshurl', auth: null, ...committishDefaults },
 
   'ssh://github.com:foo/bar.git': { ...defaults, default: 'sshurl' },
-  'ssh://github.com:foo/bar.git#branch': { ...defaults, default: 'sshurl', committish: 'branch' },
+  [`ssh://github.com:foo/bar.git#${committishDefaults.committish}`]: { ...defaults, default: 'sshurl', ...committishDefaults },
   'ssh://user@github.com:foo/bar.git': { ...defaults, default: 'sshurl', auth: null },
-  'ssh://user@github.com:foo/bar.git#branch': { ...defaults, default: 'sshurl', auth: null, committish: 'branch' },
+  [`ssh://user@github.com:foo/bar.git#${committishDefaults.committish}`]: { ...defaults, default: 'sshurl', auth: null, ...committishDefaults },
   'ssh://user:password@github.com:foo/bar.git': { ...defaults, default: 'sshurl', auth: null },
-  'ssh://user:password@github.com:foo/bar.git#branch': { ...defaults, default: 'sshurl', auth: null, committish: 'branch' },
+  [`ssh://user:password@github.com:foo/bar.git#${committishDefaults.committish}`]: { ...defaults, default: 'sshurl', auth: null, ...committishDefaults },
   'ssh://:password@github.com:foo/bar.git': { ...defaults, default: 'sshurl', auth: null },
-  'ssh://:password@github.com:foo/bar.git#branch': { ...defaults, default: 'sshurl', auth: null, committish: 'branch' },
+  [`ssh://:password@github.com:foo/bar.git#${committishDefaults.committish}`]: { ...defaults, default: 'sshurl', auth: null, ...committishDefaults },
 
   // git+https urls
   //
   // NOTE auth is accepted and respected
   'git+https://github.com/foo/bar': { ...defaults, default: 'https' },
-  'git+https://github.com/foo/bar#branch': { ...defaults, default: 'https', committish: 'branch' },
+  [`git+https://github.com/foo/bar#${committishDefaults.committish}`]: { ...defaults, default: 'https', ...committishDefaults },
   'git+https://user@github.com/foo/bar': { ...defaults, default: 'https', auth: 'user' },
-  'git+https://user@github.com/foo/bar#branch': { ...defaults, default: 'https', auth: 'user', committish: 'branch' },
+  [`git+https://user@github.com/foo/bar#${committishDefaults.committish}`]: { ...defaults, default: 'https', auth: 'user', ...committishDefaults },
   'git+https://user:password@github.com/foo/bar': { ...defaults, default: 'https', auth: 'user:password' },
-  'git+https://user:password@github.com/foo/bar#branch': { ...defaults, default: 'https', auth: 'user:password', committish: 'branch' },
+  [`git+https://user:password@github.com/foo/bar#${committishDefaults.committish}`]: { ...defaults, default: 'https', auth: 'user:password', ...committishDefaults },
   'git+https://:password@github.com/foo/bar': { ...defaults, default: 'https', auth: ':password' },
-  'git+https://:password@github.com/foo/bar#branch': { ...defaults, default: 'https', auth: ':password', committish: 'branch' },
+  [`git+https://:password@github.com/foo/bar#${committishDefaults.committish}`]: { ...defaults, default: 'https', auth: ':password', ...committishDefaults },
 
   'git+https://github.com/foo/bar.git': { ...defaults, default: 'https' },
-  'git+https://github.com/foo/bar.git#branch': { ...defaults, default: 'https', committish: 'branch' },
+  [`git+https://github.com/foo/bar.git#${committishDefaults.committish}`]: { ...defaults, default: 'https', ...committishDefaults },
   'git+https://user@github.com/foo/bar.git': { ...defaults, default: 'https', auth: 'user' },
-  'git+https://user@github.com/foo/bar.git#branch': { ...defaults, default: 'https', auth: 'user', committish: 'branch' },
+  [`git+https://user@github.com/foo/bar.git#${committishDefaults.committish}`]: { ...defaults, default: 'https', auth: 'user', ...committishDefaults },
   'git+https://user:password@github.com/foo/bar.git': { ...defaults, default: 'https', auth: 'user:password' },
-  'git+https://user:password@github.com/foo/bar.git#branch': { ...defaults, default: 'https', auth: 'user:password', committish: 'branch' },
+  [`git+https://user:password@github.com/foo/bar.git#${committishDefaults.committish}`]: { ...defaults, default: 'https', auth: 'user:password', ...committishDefaults },
   'git+https://:password@github.com/foo/bar.git': { ...defaults, default: 'https', auth: ':password' },
-  'git+https://:password@github.com/foo/bar.git#branch': { ...defaults, default: 'https', auth: ':password', committish: 'branch' },
+  [`git+https://:password@github.com/foo/bar.git#${committishDefaults.committish}`]: { ...defaults, default: 'https', auth: ':password', ...committishDefaults },
 
   // https urls
   //
   // NOTE auth is accepted and respected
   'https://github.com/foo/bar': { ...defaults, default: 'https' },
-  'https://github.com/foo/bar#branch': { ...defaults, default: 'https', committish: 'branch' },
+  [`https://github.com/foo/bar#${committishDefaults.committish}`]: { ...defaults, default: 'https', ...committishDefaults },
   'https://user@github.com/foo/bar': { ...defaults, default: 'https', auth: 'user' },
-  'https://user@github.com/foo/bar#branch': { ...defaults, default: 'https', auth: 'user', committish: 'branch' },
+  [`https://user@github.com/foo/bar#${committishDefaults.committish}`]: { ...defaults, default: 'https', auth: 'user', ...committishDefaults },
   'https://user:password@github.com/foo/bar': { ...defaults, default: 'https', auth: 'user:password' },
-  'https://user:password@github.com/foo/bar#branch': { ...defaults, default: 'https', auth: 'user:password', committish: 'branch' },
+  [`https://user:password@github.com/foo/bar#${committishDefaults.committish}`]: { ...defaults, default: 'https', auth: 'user:password', ...committishDefaults },
   'https://:password@github.com/foo/bar': { ...defaults, default: 'https', auth: ':password' },
-  'https://:password@github.com/foo/bar#branch': { ...defaults, default: 'https', auth: ':password', committish: 'branch' },
+  [`https://:password@github.com/foo/bar#${committishDefaults.committish}`]: { ...defaults, default: 'https', auth: ':password', ...committishDefaults },
 
   'https://github.com/foo/bar.git': { ...defaults, default: 'https' },
-  'https://github.com/foo/bar.git#branch': { ...defaults, default: 'https', committish: 'branch' },
+  [`https://github.com/foo/bar.git#${committishDefaults.committish}`]: { ...defaults, default: 'https', ...committishDefaults },
   'https://user@github.com/foo/bar.git': { ...defaults, default: 'https', auth: 'user' },
-  'https://user@github.com/foo/bar.git#branch': { ...defaults, default: 'https', auth: 'user', committish: 'branch' },
+  [`https://user@github.com/foo/bar.git#${committishDefaults.committish}`]: { ...defaults, default: 'https', auth: 'user', ...committishDefaults },
   'https://user:password@github.com/foo/bar.git': { ...defaults, default: 'https', auth: 'user:password' },
-  'https://user:password@github.com/foo/bar.git#branch': { ...defaults, default: 'https', auth: 'user:password', committish: 'branch' },
+  [`https://user:password@github.com/foo/bar.git#${committishDefaults.committish}`]: { ...defaults, default: 'https', auth: 'user:password', ...committishDefaults },
   'https://:password@github.com/foo/bar.git': { ...defaults, default: 'https', auth: ':password' },
-  'https://:password@github.com/foo/bar.git#branch': { ...defaults, default: 'https', auth: ':password', committish: 'branch' },
+  [`https://:password@github.com/foo/bar.git#${committishDefaults.committish}`]: { ...defaults, default: 'https', auth: ':password', ...committishDefaults },
 
   // inputs that are not quite proper but we accept anyway
   'https://www.github.com/foo/bar': { ...defaults, default: 'https' },
   'foo/bar#branch with space': { ...defaults, default: 'shortcut', committish: 'branch with space' },
+  'foo/bar#branch:with:colons': { ...defaults, default: 'shortcut', committish: 'branch:with:colons' },
   'https://github.com/foo/bar/tree/branch': { ...defaults, default: 'https', committish: 'branch' },
   'user..blerg--/..foo-js# . . . . . some . tags / / /': { ...defaults, default: 'shortcut', user: 'user..blerg--', project: '..foo-js', committish: ' . . . . . some . tags / / /' },
 }
@@ -231,18 +232,20 @@ t.test('string methods populate correctly', t => {
   t.equal(parsed.ssh(), 'git@github.com:foo/bar.git')
   t.equal(parsed.sshurl(), 'git+ssh://git@github.com/foo/bar.git')
   t.equal(parsed.edit(), 'https://github.com/foo/bar')
-  t.equal(parsed.edit('/lib/index.js'), 'https://github.com/foo/bar/edit/master/lib/index.js')
+  t.equal(parsed.edit('/lib/index.js'), 'https://github.com/foo/bar/edit/HEAD/lib/index.js')
   t.equal(parsed.edit('/lib/index.js', { committish: 'docs' }), 'https://github.com/foo/bar/edit/docs/lib/index.js')
   t.equal(parsed.browse(), 'https://github.com/foo/bar')
-  t.equal(parsed.browse('/lib/index.js'), 'https://github.com/foo/bar/tree/master/lib/index.js')
-  t.equal(parsed.browse('/lib/index.js', 'L100'), 'https://github.com/foo/bar/tree/master/lib/index.js#l100')
+  t.equal(parsed.browse('/lib/index.js'), 'https://github.com/foo/bar/tree/HEAD/lib/index.js')
+  t.equal(parsed.browse('/lib/index.js', 'L100'), 'https://github.com/foo/bar/tree/HEAD/lib/index.js#l100')
+  t.equal(parsed.browseFile('/lib/index.js'), 'https://github.com/foo/bar/blob/HEAD/lib/index.js')
+  t.equal(parsed.browseFile('/lib/index.js', 'L100'), 'https://github.com/foo/bar/blob/HEAD/lib/index.js#l100')
   t.equal(parsed.docs(), 'https://github.com/foo/bar#readme')
   t.equal(parsed.https(), 'git+https://github.com/foo/bar.git')
   t.equal(parsed.shortcut(), 'github:foo/bar')
   t.equal(parsed.path(), 'foo/bar')
-  t.equal(parsed.tarball(), 'https://codeload.github.com/foo/bar/tar.gz/master')
-  t.equal(parsed.file(), 'https://raw.githubusercontent.com/foo/bar/master/')
-  t.equal(parsed.file('/lib/index.js'), 'https://raw.githubusercontent.com/foo/bar/master/lib/index.js')
+  t.equal(parsed.tarball(), 'https://codeload.github.com/foo/bar/tar.gz/HEAD')
+  t.equal(parsed.file(), 'https://raw.githubusercontent.com/foo/bar/HEAD/')
+  t.equal(parsed.file('/lib/index.js'), 'https://raw.githubusercontent.com/foo/bar/HEAD/lib/index.js')
   t.equal(parsed.git(), 'git://github.com/foo/bar.git')
   t.equal(parsed.bugs(), 'https://github.com/foo/bar/issues')
 
