@@ -1,22 +1,18 @@
-// An example of a custom setup, useful when testing modules like pacote,
-// which do various things with these git shortcuts.
-const ghi = require('../lib/git-host-info.js')
-ghi.localhost = {
-  protocols: ['git:'],
-  domain: 'localhost',
-  extract: (url) => {
-    const [, user, project] = url.pathname.split('/')
-    return { user, project, committish: url.hash.slice(1) }
-  },
-}
-
-ghi.byShortcut['localhost:'] = 'localhost'
-ghi.byDomain.localhost = 'localhost'
-
 const HostedGit = require('..')
 const t = require('tap')
 
 t.test('supports extensions', t => {
+  // An example of a custom setup, useful when testing modules like pacote,
+  // which do various things with these git shortcuts.
+  HostedGit.addHost('localhost', {
+    protocols: ['git:'],
+    domain: 'localhost',
+    extract: (url) => {
+      const [, user, project] = url.pathname.split('/')
+      return { user, project, committish: url.hash.slice(1) }
+    },
+  })
+
   const hosted = HostedGit.fromUrl('git://localhost:12345/foo/bar')
   t.match(
     hosted,
